@@ -1,4 +1,4 @@
 from .gpytranslate import Translator
 from .types import TranslatedObject
 
-__all__ = ['Translator', 'TranslatedObject']
+__all__ = ["Translator", "TranslatedObject"]
