@@ -1,5 +1,5 @@
 from collections.abc import Mapping
-from typing import Union, Literal, Dict, List, Any
+from typing import Union, Literal, Dict, List, Any, Final
 
 import httpx
 
@@ -7,6 +7,8 @@ from .types import TranslatedObject
 
 
 class Translator:
+    __version__: Final[str] = "1.0.2"
+
     def __init__(
         self,
         proxies: Union[httpx.Proxy, Dict[str, str]] = None,
@@ -112,15 +114,15 @@ class Translator:
                 )
             )
 
-            if client != "gtx" or dt != "t":
-                return raw
+        if client != "gtx" or dt != "t":
+            return raw
 
-            if isinstance(text, str):
-                return self.parse(raw)
-            elif isinstance(text, Mapping):
-                return {k: self.parse(v) for k, v in raw.items()}
-            else:
-                return [self.parse(elem) for elem in raw]
+        if isinstance(text, str):
+            return self.parse(raw)
+        elif isinstance(text, Mapping):
+            return {k: self.parse(v) for k, v in raw.items()}
+        else:
+            return [self.parse(elem) for elem in raw]
 
     @staticmethod
     def parse(
